//
//  led.cs - an LED control for .NET (based on MCDLG led window class)
//
//  $Id: Led.cs 856 2015-01-05 17:55:13Z brian $
//
//  Copyright (c) 2006-2015 by Precision Micro Control Corp. All rights reserved.
//
using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;

namespace McapiNet
{
	/// <summary>
	/// Summary description for Led.
	/// </summary>
	[ToolboxBitmap(typeof(Led), "led.bmp")]
	public class Led : System.Windows.Forms.Control
	{
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		private Color m_off_color;
		private Color m_on_color;
		private bool  m_checked;

		/// <summary>
		/// Checked property, turns LED on or off.
		/// </summary>
		public bool Checked
		{
			get 
			{
				return m_checked;
			}
			set 
			{
				if (m_checked != value)
					Invalidate();
				m_checked = value;
			}
		}

		/// <summary>
		/// LED on color.
		/// </summary>
		public Color OnColor
		{
			get 
			{
				return m_on_color;
			}
			set 
			{
				 m_on_color = value;
			}
		}

		/// <summary>
		/// LED off color.
		/// </summary>
		public Color OffColor
		{
			get 
			{
				return m_off_color;
			}
			set 
			{
				m_off_color = value;
			}
		}

		/// <summary>
		/// Led constructor.
		/// </summary>
		public Led()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			m_checked = false;
			m_on_color = Color.FromArgb(224, 0, 0);
			m_off_color = Color.FromArgb(32, 32, 32);
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose(bool disposing)
		{
			if (disposing)
			{
				if (components != null)
					components.Dispose();
			}
			base.Dispose(disposing);
		}

		#region Component Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{

		}
		#endregion

		/// <summary>
		/// The Led paint handler.
		/// </summary>
		/// <param name="pe">Paint event.</param>
		protected override void OnPaint(PaintEventArgs pe)
		{
			Graphics graphics = pe.Graphics;

			SolidBrush textBrush = new SolidBrush(Color.Black);

			Bitmap MyImage = new Bitmap(GetType(), "led.bmp");
			MyImage.MakeTransparent(Color.FromArgb(255, 0, 255));

			Color shade = Color.FromArgb(m_on_color.R / 2, m_on_color.G / 2, m_on_color.B / 2);
			for (int y = 0; y < MyImage.Height; y++)
				for (int x = 0; x < MyImage.Width; x++)
					if (MyImage.GetPixel(x, y) == Color.FromArgb(255,0,0))
						MyImage.SetPixel(x, y, m_checked ? m_on_color : m_off_color);
					else if (MyImage.GetPixel(x, y) == Color.FromArgb(128,0,0))
						MyImage.SetPixel(x, y, shade);

			if (RightToLeft == System.Windows.Forms.RightToLeft.Yes)
			{
				graphics.DrawString(Text, Font, textBrush, 0, 0);
				graphics.DrawImage(MyImage, Width - 12, 0, 12, 12);
			}
			else
			{
				graphics.DrawString(Text, Font, textBrush, 12, 0);
				graphics.DrawImage(MyImage, 0, 0, 12, 12);
			}

			base.OnPaint(pe);
		}
	}
}
